getCurrentOpenWeather: Get current weather from OpenWeather...

Description Usage Arguments Details Examples

View source: R/openWeather_API.R

Description

The forecast are retrived from Open Weather One Call API link.

Usage

1
getCurrentOpenWeather(lat, long, KEY)

Arguments

lat

character latitude

long

character longitude

KEY

character API key. Users must register to obtain it. See link.

Details

getCurrentOpenWeather returns a dataframe with date, temperature (Celsius scale), relative humidity (RH)(%), windSpeed (m/s), windDegree, pressure, clouds, and conditionsID and description link

In not all locations OpenWeather provides rain data, in this case the dataframe contains NA for the precipitation column.

The 'date' variable is given in local timezone.

Examples

1
2
3
4
5
## Not run: 
key.ow <- "OW-API-KEY"
getForecastOpenWeather(lat = "37.9929600", long = "-1.5366100", KEY = key.ow)

## End(Not run)

VicenteYago/meteoForecast documentation built on Dec. 18, 2021, 6:16 p.m.