getForecastOpenWeather: Get 48 h forecast from OpenWeather...

Description Usage Arguments Details Examples

View source: R/openWeather_API.R

Description

The forecast are retrived from Open Weather One Call API link.

Usage

1
getForecastOpenWeather(lat, long, KEY)

Arguments

lat

character latitude

long

character longitude

KEY

character API key. Users must register to obtain it. See link.

Details

getForecastOpenWeather returns a dataframe with date, temperature (Celsius scale), relative humidity (RH)(%), rainfall (mm) and wind (m/s). In not all locations OpenWeather provides rain data, in this case the dataframe contains NA for the precipitation column.

Examples

1
2
3
4
5
## Not run: 
key.ow <- "OW-API-KEY"
getForecastOpenWeather(lat = "37.9929600", long = "-1.5366100", KEY = key.ow)

## End(Not run)

VicenteYago/meteoForecast documentation built on Dec. 18, 2021, 6:16 p.m.