Description Usage Arguments Details Examples
View source: R/openWeather_API.R
The forecast are retrived from Open Weather One Call API link.
1 | getCurrentOpenWeather(lat, long, KEY)
|
lat |
character latitude |
long |
character longitude |
KEY |
character API key. Users must register to obtain it. See link. |
getCurrentOpenWeather returns a dataframe with date, temperature (Celsius scale), relative humidity (RH)(%),
windSpeed (m/s), windDegree, pressure, clouds, and conditionsID and description link
In not all locations OpenWeather provides rain data, in this case the dataframe contains NA for the precipitation column.
The 'date' variable is given in local timezone.
1 2 3 4 5 | ## Not run:
key.ow <- "OW-API-KEY"
getForecastOpenWeather(lat = "37.9929600", long = "-1.5366100", KEY = key.ow)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.