Each forecast provider has its own particularities when it comes to data availability, this package aims to standardize the data in a single format.
At the moment the following variables are retrieved: temperature (Celsius scale), relative humidity (RH)(%), rainfall (mm) and wind (m/s). Each forecast provider updates its forecasts at a different rate, which creates differences for the start and end date of the forecasts.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.